ExpandableFabDirection enum

The direction in which an ExpandableFab fans out its actions.

Inheritance
Available extensions

Values

up → const ExpandableFabDirection

Actions stack vertically above the main button.

down → const ExpandableFabDirection

Actions stack vertically below the main button.

left → const ExpandableFabDirection

Actions stack horizontally to the left of the main button.

Actions stack horizontally to the right of the main button.

radial → const ExpandableFabDirection

Actions fan out on an arc around the main button. The arc is described by ExpandableFab.radialStartAngle and ExpandableFab.radialSweepAngle.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ExpandableFabDirection>
A constant List of the values in this enum, in order of their declaration.