MicroNavigator class abstract final

Static navigation helpers that push pages with a MicroPageRoute.

MicroNavigator.push(
  context,
  const DetailPage(),
  type: MicroTransitionType.slideRight,
);

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

push<T extends Object?>(BuildContext context, Widget page, {MicroTransitionType type = MicroTransitionType.fade, Duration duration = const Duration(milliseconds: 300), Duration reverseDuration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut, Alignment? alignment, bool fullscreenDialog = false, bool maintainState = true}) Future<T?>
Pushes page with a MicroPageRoute of the given type.
pushAndRemoveUntil<T extends Object?>(BuildContext context, Widget page, RoutePredicate predicate, {MicroTransitionType type = MicroTransitionType.fade, Duration duration = const Duration(milliseconds: 300), Duration reverseDuration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut, Alignment? alignment, bool fullscreenDialog = false, bool maintainState = true}) Future<T?>
Pushes page with a MicroPageRoute and removes previous routes until predicate returns true.
pushReplacement<T extends Object?, TO extends Object?>(BuildContext context, Widget page, {MicroTransitionType type = MicroTransitionType.fade, Duration duration = const Duration(milliseconds: 300), Duration reverseDuration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut, Alignment? alignment, bool fullscreenDialog = false, bool maintainState = true, TO? result}) Future<T?>
Replaces the current route with page using a MicroPageRoute.